@@ -1819,7 +1819,7 @@ execute_nasl_script(struct arglist * script_infos, const char* name, const char
 
      tc.type = CONST_DATA;
      p = strrchr(name, '/');
-     if (p == NULL) p = name; else p ++;
+     if (p == NULL) p = (char*)name; else p ++;
      tc.x.str_val = p;
      tc.size = strlen(p);
      add_named_var_to_ctxt(lexic, "SCRIPT_NAME", &tc);
