@@ -247,6 +247,7 @@ static init_func libfuncs[] = {
   { "length", "pcap_active", "pcap_filter", "pcap_timeout", NULL },
   
   "pcap_next", nasl_pcap_next, 1, { "interface", "pcap_filter", "timeout", NULL},
+  "send_capture", nasl_send_capture, 1, { "data", "interface", "length", "option", "pcap_filter", "socket", "timeout", NULL},
   
 #ifdef HAVE_SSL
 #ifdef HAVE_OPENSSL_MD2_H
@@ -305,6 +306,16 @@ static init_func libfuncs[] = {
   NULL, NULL, 0, { NULL }
 } ;
 
+/* String variables */
+static struct {
+  const char	*name;
+  const char	*val;
+} libsvars[] = {
+  "NESSUS_VERSION", VERSION,
+  NULL, NULL, 
+};
+
+/* Integer variables */
 static struct {
   const char	*name;
   int		val;
@@ -408,6 +419,20 @@ int init_nasl_library(lex_ctxt* lexic)
       c ++;
     }
 
+  tc.type = CONST_DATA;
+  for (i = 0; i < sizeof(libsvars) / sizeof(libsvars[0])-1; i ++)
+    {
+      tc.x.str_val = libsvars[i].val;
+      tc.size = strlen(libsvars[i].val);
+      if ((v = add_named_var_to_ctxt(lexic, libsvars[i].name, &tc)) == NULL)
+	{
+	  nasl_perror(lexic, "init_nasl2_library: could not define var '%s'\n",
+		  libsvars[i].name);
+	  continue;
+	}
+      c ++;
+    }
+
   if (add_named_var_to_ctxt(lexic, "NULL", NULL) == NULL)
     nasl_perror(lexic, "init_nasl2_library: could not define var 'NULL'\n");
 
