@@ -600,7 +600,7 @@ tree_cell * get_kb_list(lex_ctxt * lexic)
   else if(res->type == KB_TYPE_STR)
   {
    v.var_type = VAR2_DATA;
-   v.v.v_str.s_val = res->v.v_str;
+   v.v.v_str.s_val = (unsigned char*)res->v.v_str;
    v.v.v_str.s_siz = strlen(res->v.v_str);
    add_var_to_array(a, res->name, &v);
    num_elems ++;
