@@ -25,6 +25,7 @@
 #include "nasl_var.h"
 #include "nasl_lex_ctxt.h"
 #include "exec.h"
+#include "nasl_socket.h"
 
 #include "nasl_debug.h"
 #include "capture_packet.h"
@@ -455,7 +456,7 @@ tree_cell*	forge_tcp_packet(lex_ctxt* lexic)
 
 tree_cell * get_tcp_element(lex_ctxt * lexic)
 {
- u_char * packet = get_str_local_var_by_name(lexic, "tcp");
+ u_char * packet = (u_char*)get_str_local_var_by_name(lexic, "tcp");
  struct ip * ip;
  int	ipsz;
  struct tcphdr * tcp;
@@ -614,7 +615,7 @@ tree_cell * dump_tcp_packet(lex_ctxt * lexic)
 {
  int i = 0;
  u_char * pkt;
- while((pkt = (char*)get_str_var_by_num(lexic, i++)) != NULL)
+ while((pkt = (u_char*)get_str_var_by_num(lexic, i++)) != NULL)
  {
     int a=0;
     struct ip * ip = (struct ip*)pkt;
@@ -742,7 +743,7 @@ tree_cell * forge_udp_packet(lex_ctxt * lexic)
   
   retc = alloc_tree_cell(0, NULL);
   retc->type = CONST_DATA;
-  retc->x.str_val = pkt;
+  retc->x.str_val = (char*)pkt;
   retc->size = 8 + ip->ip_hl * 4 + data_len;
   return retc;
  }
@@ -927,7 +928,7 @@ tree_cell * dump_udp_packet(lex_ctxt * lexic)
 {
  int i = 0;
  u_char * pkt;
- while((pkt = get_str_var_by_num(lexic, i++)) != NULL)
+ while((pkt = (u_char*)get_str_var_by_num(lexic, i++)) != NULL)
  {
    struct udphdr * udp = (struct udphdr*)(pkt+sizeof(struct ip));
    int j;
@@ -1009,7 +1010,7 @@ tree_cell*	forge_icmp_packet(lex_ctxt* lexic)
       
       retc = alloc_tree_cell(0, NULL);
       retc->type = CONST_DATA;
-      retc->x.str_val = pkt;
+      retc->x.str_val = (char*)pkt;
       retc->size = ip_sz + len + 8;
     }
   else
@@ -1138,7 +1139,7 @@ tree_cell * forge_igmp_packet(lex_ctxt * lexic)
   }
    retc = alloc_tree_cell(0, NULL);
    retc->type = CONST_DATA;
-   retc->x.str_val = pkt;
+   retc->x.str_val = (char*)pkt;
    retc->size = ip->ip_hl * 4 + sizeof(struct igmp) + len;
    return retc;
   }
@@ -1223,7 +1224,7 @@ tree_cell * nasl_tcp_ping(lex_ctxt * lexic)
  if(islocalhost(dst) != 0)flag++;
  else
  {
-  while((i < 20) && (!flag))
+  for(i = 0; i < sizeof(sports) / sizeof(int) && ! flag; i ++)
   {
    bzero(packet, sizeof(packet));
   /* IP */
@@ -1373,7 +1374,7 @@ tree_cell*	nasl_send_packet(lex_ctxt* lexic)
 	    {
   	      retc = alloc_tree_cell(0, NULL);
   	      retc->type = CONST_DATA;
-	      retc->x.str_val = answer;
+	      retc->x.str_val = (char*)answer;
 	      retc->size = answer_sz;
               break;
 	    }
@@ -1472,3 +1473,92 @@ tree_cell * nasl_pcap_next(lex_ctxt* lexic)
  
  return retc;
 }
+
+tree_cell * nasl_send_capture(lex_ctxt* lexic)
+{
+ char * interface = get_str_local_var_by_name(lexic, "interface");
+ int bpf = -1;
+ static char errbuf[PCAP_ERRBUF_SIZE];
+ int is_ip = 0;
+ struct ip * ret = NULL;
+ char *filter = get_str_local_var_by_name(lexic, "pcap_filter");
+ int timeout = get_int_local_var_by_name(lexic, "timeout", 5);
+ tree_cell * retc;
+ int sz;
+ struct in_addr * dst = plug_get_host_ip(lexic->script_infos);
+
+ if(interface == NULL )
+ 	{
+	struct in_addr src;
+	bzero(&src, sizeof(src));
+    	interface = routethrough(dst, &src);
+	if( interface == NULL )interface = pcap_lookupdev(errbuf);
+	}
+	
+ if(interface != NULL)
+  bpf = bpf_open_live(interface, filter);
+ 
+ 
+ if(bpf < 0)
+  {
+   nasl_perror(lexic, "pcap_next: Could not get a bpf\n");
+   return NULL;
+  }
+ else
+ {
+  int len;
+  int dl_len = get_datalink_size(bpf_datalink(bpf));
+  char * packet;
+  struct timeval then, now;
+  
+  
+  retc = nasl_send(lexic); 
+  efree(&retc);
+
+  gettimeofday(&then, NULL);
+  for(;;)
+  {
+  packet = (char*)bpf_next(bpf, &len);
+  
+  if(packet != NULL)
+  	break;
+	
+  if(timeout != 0)
+   {
+    gettimeofday(&now, NULL);
+    if(now.tv_sec - then.tv_sec >= timeout)break;
+   }
+  }
+
+  if(packet)
+  {
+   struct ip * ip;   
+   ip = (struct ip*)(packet + dl_len);
+   sz = UNFIX(ip->ip_len);
+   ret = emalloc(sz);
+  
+   is_ip = (ip->ip_v == 4);
+   if(is_ip)
+   {
+	
+	 bcopy(ip, ret, sz);
+   }
+   else {
+	   sz = len - dl_len;
+	   bcopy(ip, ret, sz);
+   }
+  }
+  else {
+    bpf_close(bpf);
+    return NULL;
+  }
+ }
+ bpf_close(bpf);
+ retc = alloc_tree_cell(0, NULL);
+ 
+ retc->type = CONST_DATA;
+ retc->x.str_val = (char*)ret;
+ retc->size = sz;
+ 
+ return retc;
+}
