@@ -161,7 +161,8 @@ static tree_cell * nasl_open_privileged_socket(lex_ctxt * lexic, int proto)
  tree_cell * retc;
  struct timeval tv;
  fd_set rd;
- int opt, opt_sz;
+ int opt;
+ unsigned int opt_sz;
  
  
  
@@ -193,7 +194,7 @@ restart:
 	 return NULL;
 
 tryagain :
- if ( current_sport < 128 ) return NULL;
+ if ( current_sport < 128 && sport < 0 ) return NULL;
  e =  set_socket_source_addr(sock, sport > 0 ? sport : current_sport--);
  
  /*
@@ -354,6 +355,7 @@ tree_cell * nasl_open_sock_udp(lex_ctxt * lexic)
 	 return NULL;
    
  ia = plug_get_host_ip(script_infos);
+ if ( ia == NULL ) return NULL;
  bzero(&soca, sizeof(soca));
  soca.sin_addr.s_addr = ia->s_addr;
  soca.sin_port = htons(port);
@@ -384,7 +386,8 @@ tree_cell * nasl_recv(lex_ctxt * lexic)
  struct timeval tv;
  int new_len = 0;
  tree_cell * retc;
- int type = -1, opt_len = sizeof(type);
+ int type = -1;
+ unsigned int opt_len = sizeof(type);
  int e;
  
 
@@ -552,7 +555,8 @@ tree_cell * nasl_send(lex_ctxt * lexic)
  int length = get_int_local_var_by_name(lexic, "length", 0);
  int n;
  tree_cell * retc;
- int type, type_len = sizeof(type);
+ int type;
+ unsigned int type_len = sizeof(type);
 
  
  if(soc <= 0 || data == NULL)
@@ -591,7 +595,7 @@ tree_cell * nasl_close_socket(lex_ctxt * lexic)
 {
  int soc;
  int type;
- int opt_len = sizeof(type);
+ unsigned int opt_len = sizeof(type);
  int e;
  
  soc = get_int_var_by_num(lexic, 0, -1);
@@ -736,8 +740,11 @@ tree_cell*
 nasl_get_source_port(lex_ctxt* lexic)
 {
   struct sockaddr_in	ia;
-  int		i, s, fd, l;
+  int		i, s, fd;
+  unsigned  int	l;
   tree_cell	*retc;
+  int         type;
+  unsigned int type_len = sizeof(type);
 
   s = get_int_var_by_num(lexic, 0, -1);
   if (s < 0)
@@ -745,7 +752,12 @@ nasl_get_source_port(lex_ctxt* lexic)
       nasl_perror(lexic, "get_source_port: missing socket parameter\n");
       return NULL;
     }
-  fd = nessus_get_socket_from_connection(s);
+  if(!fd_is_stream(s) && getsockopt(s, SOL_SOCKET, SO_TYPE, &type, &type_len) == 0 && type == SOCK_DGRAM)
+       fd = s;
+   else
+       fd = nessus_get_socket_from_connection(s);
+ 
+
   if (fd < 0)
     {
       nasl_perror(lexic, "get_source_port: invalid socket parameter %d\n", s);
