@@ -363,7 +363,7 @@ tree_cell* nasl_hexstr(lex_ctxt * lexic)
 tree_cell* nasl_ord(lex_ctxt* lexic)
 {
   tree_cell	*retc;
-  unsigned char	*val = get_str_var_by_num(lexic, 0);
+  unsigned char	*val = (unsigned char*)get_str_var_by_num(lexic, 0);
 
  
   if (val == NULL)
@@ -640,6 +640,8 @@ tree_cell* nasl_ereg_replace(lex_ctxt* lexic)
   }
 
  r = _regreplace(pattern, replace, string, icase, 1);
+ if ( r == NULL )
+	return FAKE_CELL;
  
  retc = alloc_tree_cell(0, NULL);
  retc->type = CONST_DATA;
@@ -798,7 +800,7 @@ nasl_eregmatch(lex_ctxt* lexic)
       {
 	v.var_type = VAR2_DATA;
 	v.v.v_str.s_siz = subs[i].rm_eo - subs[i].rm_so;
-	v.v.v_str.s_val = string + subs[i].rm_so;
+	v.v.v_str.s_val = (unsigned char*)string + subs[i].rm_so;
 	(void) add_var_to_list(a, i, &v);
       }
 
@@ -919,12 +921,12 @@ nasl_match(lex_ctxt* lexic)
   if (pattern == NULL)
     {
       nasl_perror(lexic, "nasl_match: parameter 'pattern' missing\n");
-      pattern = "";
+      return NULL;
     }
   if (string == NULL)
     {
       nasl_perror(lexic, "nasl_match: parameter 'string' missing\n");
-      string = "";
+      return NULL;
     }
 
   retc = alloc_tree_cell(0, NULL);
@@ -977,7 +979,7 @@ nasl_split(lex_ctxt* lexic)
 	  if ((p = (char*)memmem(str + i, len - i, sep, sep_len)) == NULL)
 	    {
 	      v.v.v_str.s_siz = len - i;
-	      v.v.v_str.s_val = str + i;
+	      v.v.v_str.s_val = (unsigned char*)str + i;
 	      (void) add_var_to_list(a, j ++, &v);
 	      return retc;
 	    }
@@ -987,7 +989,7 @@ nasl_split(lex_ctxt* lexic)
 		v.v.v_str.s_siz = (p - (str + i)) + sep_len;
 	      else
 		v.v.v_str.s_siz = p - (str + i); 
-	      v.v.v_str.s_val = str + i;
+	      v.v.v_str.s_val = (unsigned char*)str + i;
 	      (void) add_var_to_list(a, j ++, &v);
 	      i = (p - str) + sep_len;
 	      if (i >= len)
@@ -1006,7 +1008,7 @@ nasl_split(lex_ctxt* lexic)
 	    v.v.v_str.s_siz = i - i0 + 1;
 	  else
 	    v.v.v_str.s_siz = i - i0 - 1;
-	  v.v.v_str.s_val = str + i0;
+	  v.v.v_str.s_val = (unsigned char*)str + i0;
 	  i0 = i + 1;
 	  (void) add_var_to_list(a, j ++, &v);
 	}
@@ -1016,7 +1018,7 @@ nasl_split(lex_ctxt* lexic)
 	    v.v.v_str.s_siz = i - i0 + 1;
 	  else
 	    v.v.v_str.s_siz = i - i0;
-	  v.v.v_str.s_val = str + i0;
+	  v.v.v_str.s_val = (unsigned char*)str + i0;
 	  i0 = i + 1;
 	  (void) add_var_to_list(a, j ++, &v);
 	}
@@ -1025,7 +1027,7 @@ nasl_split(lex_ctxt* lexic)
   if (i > i0)
     {
       v.v.v_str.s_siz = i - i0;
-      v.v.v_str.s_val = str + i0;
+      v.v.v_str.s_val = (unsigned char*)str + i0;
       (void) add_var_to_list(a, j ++, &v);
     }
   return retc;
